<?php
/**
 * Poynt — a GoDaddy Brand for WooCommerce
 *
 * @author GoDaddy
 * @copyright Copyright (c) 2021 GoDaddy Operating Company, LLC. All Rights Reserved.
 * @license GPL-2.0
 */

namespace GoDaddy\WooCommerce\Poynt\Gateways;

use SkyVerge\WooCommerce\PluginFramework\v5_10_3 as Framework;
use WC_Customer;
use WC_Order;

defined('ABSPATH') or exit;

/**
 * Payment form handler.
 *
 * @since 1.0.0
 *
 * @method CreditCardGateway get_gateway()
 */
class PaymentForm extends Framework\SV_WC_Payment_Gateway_Payment_Form
{
    /**
     * Gets the JavaScript class name.
     *
     * @since 1.0.0
     *
     * @return string
     */
    protected function get_js_handler_class_name() : string
    {
        return 'WC_Poynt_Payment_Form_Handler';
    }

    /**
     * Gets the JavaScript handler arguments.
     *
     * @since 1.0.0
     *
     * @return array
     */
    protected function get_js_handler_args() : array
    {
        $args = parent::get_js_handler_args();

        $args['appId']            = $this->get_gateway()->getAppId();
        $args['businessId']       = $this->get_gateway()->getBusinessId();
        $args['customerName']     = $this->getCustomerName();
        $args['customerAddress']  = $this->getCustomerAddress();
        $args['isLoggingEnabled'] = ! $this->get_gateway()->debug_off();

        return $args;
    }

    /**
     * Renders the payment fields HTML.
     *
     * @internal
     *
     * @since 1.0.0
     */
    public function render_payment_fields()
    {
        $gateway = $this->get_gateway();

        ?>
        <input type="hidden" name="wc_<?php echo $gateway->get_id(); ?>_nonce" id="wc-<?php echo $gateway->get_id_dasherized(); ?>-nonce">
        <div id="wc-poynt-credit-card-hosted-form"></div>
        <?php
    }

    /**
     * Gets the current customer's name.
     *
     * @since 1.1.2
     *
     * @return array
     */
    private function getCustomerName() : array
    {
        $name = [
            'firstName' => '',
            'lastName'  => '',
        ];

        // if on the checkout pay page use the order's billing name details
        if (is_checkout_pay_page()) {

            $order = wc_get_order($this->get_gateway()->get_checkout_pay_page_order_id());

            if ($order instanceof WC_Order) {
                $name['firstName'] = $order->get_billing_first_name();
                $name['lastName']  = $order->get_billing_last_name();
            }

            return $name;
        }

        // get the current customer's name if available
        if (WC()->customer instanceof WC_Customer) {
            $name['firstName'] = WC()->customer->get_first_name();
            $name['lastName']  = WC()->customer->get_last_name();
        }

        return $name;
    }

    /**
     * Gets the current customer's address.
     *
     * @since 1.0.0
     *
     * @return array
     */
    private function getCustomerAddress() : array
    {
        $address = [
            'line1'    => '',
            'postcode' => '',
        ];

        // if on the checkout pay page use the order's address details
        if (is_checkout_pay_page()) {

            $order = wc_get_order($this->get_gateway()->get_checkout_pay_page_order_id());

            if ($order instanceof WC_Order) {
                $address['line1']    = $order->get_billing_address_1();
                $address['postcode'] = $order->get_billing_postcode();
            }

            return $address;
        }

        // get the current customer's address details if available
        if (WC()->customer instanceof WC_Customer) {
            $address['line1']    = WC()->customer->get_billing_address_1();
            $address['postcode'] = WC()->customer->get_billing_postcode();
        }

        return $address;
    }
}
